AprsData

Enum AprsData 

pub enum AprsData<'a> {
Show 19 variants Status { text: &'a [u8], }, Position(Position<'a>), TimestampedPosition(TimestampedPosition<'a>), CompressedPosition(CompressedPosition<'a>), Message(Message<'a>), Object(Object<'a>), Item(Item<'a>), Weather(Weather<'a>), Telemetry(Telemetry<'a>), TelemetryMetadata(TelemetryMetadata<'a>), Query(Query<'a>), Capability(Capability<'a>), Nmea(Nmea<'a>), MicE(MicE<'a>), Maidenhead(Maidenhead<'a>), UserDefined(UserDefined<'a>), ThirdParty(ThirdParty<'a>), Unsupported { identifier: u8, information: &'a [u8], }, Malformed { identifier: u8, information: &'a [u8], },
}
Semantic APRS information-field data.

Variants



Status

Status report.

Fields

text: &'a [u8]

Status text bytes.



Position(Position<'a>)

Uncompressed position report.



TimestampedPosition(TimestampedPosition<'a>)

Timestamped uncompressed position report.



CompressedPosition(CompressedPosition<'a>)

Compressed position report.



Message(Message<'a>)

Message, bulletin, or announcement.



Object(Object<'a>)

Object report.



Item(Item<'a>)

Item report.



Weather(Weather<'a>)

Weather report without position.



Telemetry(Telemetry<'a>)

Telemetry report.



TelemetryMetadata(TelemetryMetadata<'a>)

Telemetry metadata carried as an APRS message.



Query(Query<'a>)

Query packet.



Capability(Capability<'a>)

Station capabilities packet.



Nmea(Nmea<'a>)

NMEA sentence packet.



MicE(MicE<'a>)

Mic-E packet.



Maidenhead(Maidenhead<'a>)

Maidenhead locator packet.



UserDefined(UserDefined<'a>)

User-defined data packet.



ThirdParty(ThirdParty<'a>)

Third-party traffic packet.



Unsupported

Data format is validly framed but not implemented yet.

Fields

identifier: u8

Original data type identifier byte.

information: &'a [u8]

Remaining information-field bytes.



Malformed

Data type is known, but its information bytes are malformed.

Fields

identifier: u8

Original data type identifier byte.

information: &'a [u8]

Remaining information-field bytes.

Implementations

Source

impl AprsData<'_>

pub fn kind_name(&self) -> &'static str

Returns a stable semantic kind name for diagnostics.