DataTypeIdentifier

Enum DataTypeIdentifier 

pub enum DataTypeIdentifier {
Show 19 variants PositionNoTimestamp, PositionNoTimestampMessaging, PositionWithTimestamp, PositionWithTimestampMessaging, Status, Query, Capability, Message, Object, Item, Weather, Telemetry, Nmea, MicECurrent, MicEOld, Maidenhead, UserDefined, ThirdParty, Unknown(u8),
}
APRS data type identifier from the first payload byte.

Variants



PositionNoTimestamp

!: position without timestamp, no APRS messaging.



PositionNoTimestampMessaging

=: position without timestamp, APRS messaging supported.



PositionWithTimestamp

/: position with timestamp, no APRS messaging.



PositionWithTimestampMessaging

@: position with timestamp, APRS messaging supported.



Status

>: status.



Query

?: query.



Capability

<: station capabilities.



Message

:: message, bulletin, or announcement.



Object

;: object.



Item

): item.



Weather

_: weather report without position.



Telemetry

T: telemetry.



Nmea

$: NMEA sentence.



MicECurrent

`: current Mic-E data.



MicEOld

': old Mic-E data.



Maidenhead

[: Maidenhead locator.



UserDefined

{: user-defined data.



ThirdParty

}: third-party traffic.



Unknown(u8)

Any currently unclassified identifier byte.

Implementations

Source

impl DataTypeIdentifier

pub fn name(self) -> &'static str

Returns a stable data type identifier name for diagnostics.