pub fn parse_packet_with_options(
input: &[u8],
options: ParseOptions,
) -> Result<ParsedPacket, ParseError>Expand description
Parses an APRS packet from untrusted bytes with explicit codec options.
pub fn parse_packet_with_options(
input: &[u8],
options: ParseOptions,
) -> Result<ParsedPacket, ParseError>Parses an APRS packet from untrusted bytes with explicit codec options.