DuplicateDecision

Enum DuplicateDecision 

pub enum DuplicateDecision {
    New,
    Duplicate,
}
Duplicate suppression decision for a packet byte sequence.

Variants



New

Packet bytes were not seen in the retained window.



Duplicate

Packet bytes match a retained packet in the window.

Implementations

Source

impl DuplicateDecision

pub const fn code(self) -> &'static str

Stable machine-readable decision code.