CompressedPosition

Struct CompressedPosition 

pub struct CompressedPosition<'a> {
    pub messaging: bool,
    pub symbol_table: u8,
    pub compressed_latitude: &'a [u8],
    pub compressed_longitude: &'a [u8],
    pub symbol_code: u8,
    pub extension: &'a [u8],
    pub compression_type: u8,
    pub comment: &'a [u8],
}
Compressed APRS position fields.

Fields

messaging: bool

Whether the data type identifier indicates APRS messaging support.

symbol_table: u8

Symbol table identifier byte.

compressed_latitude: &'a [u8]

Four-byte compressed latitude.

compressed_longitude: &'a [u8]

Four-byte compressed longitude.

symbol_code: u8

Symbol code byte.

extension: &'a [u8]

Two-byte compressed extension field.

compression_type: u8

Compression type byte.

comment: &'a [u8]

Optional comment bytes after the compression type byte.

Implementations

Source

impl<'a> CompressedPosition<'a>

pub fn coordinates(&self) -> Option<Coordinates>

Returns decoded compressed-position coordinates.

pub fn weather(&self) -> Option<Weather<'a>>

Returns embedded weather fields when this compressed position uses the weather station symbol and carries a non-empty weather report in its comment.