Engine

Struct Engine 

pub struct Engine { /* private fields */ }
Parser and policy orchestration engine.

Implementations

Source

impl Engine

pub fn new(policy: Policy) -> Self

Creates an engine with the provided policy.

Examples found in repository?
examples/process_file.rs (line 14)
7fn main() -> std::io::Result<()> {
8    let Some(path) = std::env::args().nth(1) else {
9        eprintln!("usage: process_file <packets.aprs>");
10        std::process::exit(2);
11    };
12
13    let input = read_all_with_limit(File::open(path)?, DEFAULT_TRANSPORT_READ_LIMIT)?;
14    let mut engine = Engine::new(Policy::strict());
15
16    for packet_bytes in LineTransport::new(&input).packets() {
17        match engine.process(packet_bytes) {
18            EngineResult::Accepted { packet } => {
19                let summary = packet.summary();
20                println!(
21                    "accepted source={} destination={} semantic={}",
22                    String::from_utf8_lossy(summary.source),
23                    String::from_utf8_lossy(summary.destination),
24                    summary.semantic
25                );
26            }
27            EngineResult::Rejected { reason, .. } => eprintln!("rejected: {}", reason.code()),
28            EngineResult::ParseError(error) => eprintln!("malformed: {}", error.code()),
29        }
30    }
31
32    Ok(())
33}
More examples
Hide additional examples
examples/service_ingest.rs (line 7)
5fn main() -> Result<(), std::io::Error> {
6    let input = b"N0CALL>APRS:>service online\nN1CALL>APRS:~opaque\nbad packet\n";
7    let mut engine = Engine::new(Policy::strict());
8
9    let packets = LineTransport::new(input).packets_with_limit(MAX_PACKET_LEN)?;
10
11    for packet in packets {
12        match engine.process_event(packet) {
13            EngineEvent::Accepted(event) => {
14                println!(
15                    "event={} semantic={}",
16                    event.kind().code(),
17                    event.packet.summary().semantic
18                );
19            }
20            EngineEvent::Rejected(event) => {
21                println!(
22                    "event={} code={} remediation={}",
23                    event.kind().code(),
24                    event.diagnostic.code,
25                    event.diagnostic.remediation
26                );
27            }
28            EngineEvent::Malformed(event) => {
29                println!(
30                    "event={} code={} raw_len={} raw_truncated={} remediation={}",
31                    event.kind().code(),
32                    event.diagnostic.code,
33                    event.raw.len(),
34                    event.raw_truncated,
35                    event.diagnostic.remediation
36                );
37            }
38        }
39    }
40
41    let counters = engine.counters();
42    println!(
43        "summary accepted={} rejected={} malformed={}",
44        counters.accepted, counters.rejected, counters.malformed
45    );
46
47    Ok(())
48}
pub fn process(&mut self, input: &[u8]) -> EngineResult

Processes one packet through codec, semantics, and policy.

Examples found in repository?
examples/process_file.rs (line 17)
7fn main() -> std::io::Result<()> {
8    let Some(path) = std::env::args().nth(1) else {
9        eprintln!("usage: process_file <packets.aprs>");
10        std::process::exit(2);
11    };
12
13    let input = read_all_with_limit(File::open(path)?, DEFAULT_TRANSPORT_READ_LIMIT)?;
14    let mut engine = Engine::new(Policy::strict());
15
16    for packet_bytes in LineTransport::new(&input).packets() {
17        match engine.process(packet_bytes) {
18            EngineResult::Accepted { packet } => {
19                let summary = packet.summary();
20                println!(
21                    "accepted source={} destination={} semantic={}",
22                    String::from_utf8_lossy(summary.source),
23                    String::from_utf8_lossy(summary.destination),
24                    summary.semantic
25                );
26            }
27            EngineResult::Rejected { reason, .. } => eprintln!("rejected: {}", reason.code()),
28            EngineResult::ParseError(error) => eprintln!("malformed: {}", error.code()),
29        }
30    }
31
32    Ok(())
33}
pub fn process_event(&mut self, input: &[u8]) -> EngineEvent

Processes one packet and returns a stable observability event.

Examples found in repository?
examples/service_toolkit.rs (line 29)
10fn main() -> Result<(), libaprs_engine::ParseError> {
11    let mut engine = Engine::default();
12    let mut duplicates = DuplicateWindow::new(128);
13    let mut rate = PacketRateBudget::new(100);
14    let blocked = SemanticBlocklist::new(&[SemanticFamily::Unsupported, SemanticFamily::Malformed]);
15
16    for packet_bytes in [b"N0CALL>APRS:>service".as_slice()] {
17        if rate.try_consume() == RateLimitDecision::Limited {
18            continue;
19        }
20        if duplicates.observe(packet_bytes) == DuplicateDecision::Duplicate {
21            continue;
22        }
23
24        let packet = parse_packet(packet_bytes)?;
25        if blocked.rejects(&packet.aprs_data()) {
26            continue;
27        }
28
29        let _event = engine.process_event(packet.raw().as_bytes());
30    }
31
32    Ok(())
33}
More examples
Hide additional examples
examples/service_ingest.rs (line 12)
5fn main() -> Result<(), std::io::Error> {
6    let input = b"N0CALL>APRS:>service online\nN1CALL>APRS:~opaque\nbad packet\n";
7    let mut engine = Engine::new(Policy::strict());
8
9    let packets = LineTransport::new(input).packets_with_limit(MAX_PACKET_LEN)?;
10
11    for packet in packets {
12        match engine.process_event(packet) {
13            EngineEvent::Accepted(event) => {
14                println!(
15                    "event={} semantic={}",
16                    event.kind().code(),
17                    event.packet.summary().semantic
18                );
19            }
20            EngineEvent::Rejected(event) => {
21                println!(
22                    "event={} code={} remediation={}",
23                    event.kind().code(),
24                    event.diagnostic.code,
25                    event.diagnostic.remediation
26                );
27            }
28            EngineEvent::Malformed(event) => {
29                println!(
30                    "event={} code={} raw_len={} raw_truncated={} remediation={}",
31                    event.kind().code(),
32                    event.diagnostic.code,
33                    event.raw.len(),
34                    event.raw_truncated,
35                    event.diagnostic.remediation
36                );
37            }
38        }
39    }
40
41    let counters = engine.counters();
42    println!(
43        "summary accepted={} rejected={} malformed={}",
44        counters.accepted, counters.rejected, counters.malformed
45    );
46
47    Ok(())
48}
pub fn process_packets<I, P>(&mut self, packets: I) -> Vec<EngineResult>
where I: IntoIterator<Item = P>, P: AsRef<[u8]>,

Processes a caller-provided packet batch in order.

pub fn process_source<S>( &mut self, source: &mut S, ) -> Result<Vec<EngineResult>, S::Error>
where S: PacketSource,

Reads one bounded batch from a packet source and processes it in order.

pub fn counters(&self) -> Counters

Returns engine counters.

Examples found in repository?
examples/service_ingest.rs (line 41)
5fn main() -> Result<(), std::io::Error> {
6    let input = b"N0CALL>APRS:>service online\nN1CALL>APRS:~opaque\nbad packet\n";
7    let mut engine = Engine::new(Policy::strict());
8
9    let packets = LineTransport::new(input).packets_with_limit(MAX_PACKET_LEN)?;
10
11    for packet in packets {
12        match engine.process_event(packet) {
13            EngineEvent::Accepted(event) => {
14                println!(
15                    "event={} semantic={}",
16                    event.kind().code(),
17                    event.packet.summary().semantic
18                );
19            }
20            EngineEvent::Rejected(event) => {
21                println!(
22                    "event={} code={} remediation={}",
23                    event.kind().code(),
24                    event.diagnostic.code,
25                    event.diagnostic.remediation
26                );
27            }
28            EngineEvent::Malformed(event) => {
29                println!(
30                    "event={} code={} raw_len={} raw_truncated={} remediation={}",
31                    event.kind().code(),
32                    event.diagnostic.code,
33                    event.raw.len(),
34                    event.raw_truncated,
35                    event.diagnostic.remediation
36                );
37            }
38        }
39    }
40
41    let counters = engine.counters();
42    println!(
43        "summary accepted={} rejected={} malformed={}",
44        counters.accepted, counters.rejected, counters.malformed
45    );
46
47    Ok(())
48}