pub struct MicE<'a> {
pub identifier: u8,
pub destination: &'a [u8],
pub body: &'a [u8],
pub status: Option<MicEStatus>,
pub latitude_digits: Option<[u8; 6]>,
}Expand description
APRS Mic-E packet bytes.
Fields
identifier: u8Original Mic-E data type identifier byte.
destination: &'a [u8]Destination address bytes that carry Mic-E latitude/status data.
body: &'a [u8]Mic-E body bytes.
status: Option<MicEStatus>Destination-derived Mic-E status bits when the destination permits decoding.
latitude_digits: Option<[u8; 6]>Destination-derived six latitude digit nibbles when decodable.
Implementations
Sourceimpl MicE<'_>
impl MicE<'_>
Sourcepub fn coordinates(&self) -> Option<Coordinates>
pub fn coordinates(&self) -> Option<Coordinates>
Returns decoded Mic-E coordinates when destination and body bytes permit it.
Sourcepub fn speed_course(&self) -> Option<MicESpeedCourse>
pub fn speed_course(&self) -> Option<MicESpeedCourse>
Returns decoded Mic-E speed and course when body bytes permit it.
Sourcepub fn message_code(&self) -> Option<MicEMessageCode>
pub fn message_code(&self) -> Option<MicEMessageCode>
Returns the Mic-E destination-derived message code when decodable.