ParseOptions

Struct ParseOptions 

pub struct ParseOptions {
    pub max_packet_len: usize,
}
Codec configuration for consumers that need a different envelope limit.

The parser remains fail-closed regardless of this setting. This value only changes the maximum accepted packet length.

Fields

max_packet_len: usize

Maximum accepted packet length in bytes.

Implementations

Source

impl ParseOptions

pub const fn new(max_packet_len: usize) -> Self

Creates parse options with a custom maximum packet length.