ParsedPacket

Struct ParsedPacket 

pub struct ParsedPacket { /* private fields */ }
Structured packet view backed by the preserved raw packet bytes.

Implementations

Source

impl ParsedPacket

pub fn raw(&self) -> &RawPacket

Returns the preserved raw packet.

Examples found in repository?
examples/service_toolkit.rs (line 29)
10fn main() -> Result<(), libaprs_engine::ParseError> {
11    let mut engine = Engine::default();
12    let mut duplicates = DuplicateWindow::new(128);
13    let mut rate = PacketRateBudget::new(100);
14    let blocked = SemanticBlocklist::new(&[SemanticFamily::Unsupported, SemanticFamily::Malformed]);
15
16    for packet_bytes in [b"N0CALL>APRS:>service".as_slice()] {
17        if rate.try_consume() == RateLimitDecision::Limited {
18            continue;
19        }
20        if duplicates.observe(packet_bytes) == DuplicateDecision::Duplicate {
21            continue;
22        }
23
24        let packet = parse_packet(packet_bytes)?;
25        if blocked.rejects(&packet.aprs_data()) {
26            continue;
27        }
28
29        let _event = engine.process_event(packet.raw().as_bytes());
30    }
31
32    Ok(())
33}
More examples
Hide additional examples
examples/encode_packets.rs (line 15)
8fn main() -> Result<(), Box<dyn std::error::Error>> {
9    let path = [b"APRS".as_slice(), b"WIDE1-1".as_slice()];
10
11    let status = encode_status(b"N0CALL", &path, b"encoder example")?;
12    assert_eq!(
13        parse_packet(&status)
14            .map_err(|error| std::io::Error::new(std::io::ErrorKind::InvalidData, error.code()))?
15            .raw()
16            .as_bytes(),
17        b"N0CALL>APRS,WIDE1-1:>encoder example"
18    );
19
20    let position = encode_uncompressed_position(
21        b"N0CALL",
22        &path,
23        UncompressedPositionEncoding {
24            messaging: false,
25            latitude: b"4903.50N",
26            symbol_table: b'/',
27            longitude: b"07201.75W",
28            symbol_code: b'-',
29            comment: b"encoded",
30        },
31    )?;
32    assert_eq!(
33        parse_packet(&position)
34            .map_err(|error| std::io::Error::new(std::io::ErrorKind::InvalidData, error.code()))?
35            .summary()
36            .semantic,
37        "position"
38    );
39
40    let telemetry = encode_telemetry(b"N0CALL", &path, 1, [111, 222, 33, 44, 55], None)?;
41    assert_eq!(
42        parse_packet(&telemetry)
43            .map_err(|error| std::io::Error::new(std::io::ErrorKind::InvalidData, error.code()))?
44            .summary()
45            .semantic,
46        "telemetry"
47    );
48
49    Ok(())
50}
pub fn source(&self) -> &[u8]

Returns the source callsign bytes before the > separator.

Examples found in repository?
examples/parse_packet.rs (line 6)
3fn main() -> Result<(), libaprs_engine::ParseError> {
4    let packet = parse_packet(b"N0CALL>APRS:>hello")?;
5
6    println!("source={}", String::from_utf8_lossy(packet.source()));
7    println!(
8        "destination={}",
9        String::from_utf8_lossy(packet.destination())
10    );
11
12    if let AprsData::Status { text } = packet.aprs_data() {
13        println!("status={}", String::from_utf8_lossy(text));
14    }
15
16    Ok(())
17}
pub fn path(&self) -> &[u8]

Returns the destination/path bytes between > and :.

pub fn destination(&self) -> &[u8]

Returns the destination bytes, which are the first path component.

Examples found in repository?
examples/parse_packet.rs (line 9)
3fn main() -> Result<(), libaprs_engine::ParseError> {
4    let packet = parse_packet(b"N0CALL>APRS:>hello")?;
5
6    println!("source={}", String::from_utf8_lossy(packet.source()));
7    println!(
8        "destination={}",
9        String::from_utf8_lossy(packet.destination())
10    );
11
12    if let AprsData::Status { text } = packet.aprs_data() {
13        println!("status={}", String::from_utf8_lossy(text));
14    }
15
16    Ok(())
17}
pub fn digipeaters(&self) -> Vec<&[u8]>

Returns digipeater path component byte views after the destination.

pub fn path_components(&self) -> Vec<&[u8]>

Returns all path component byte views, including destination first.

pub fn payload(&self) -> &[u8]

Returns the payload bytes after the : separator.

pub fn data_type_identifier(&self) -> DataTypeIdentifier

Returns the APRS data type identifier from the first payload byte.

pub fn information(&self) -> &[u8]

Returns payload bytes after the data type identifier.

pub fn aprs_data(&self) -> AprsData<'_>

Returns a semantic view of the APRS information field.

Examples found in repository?
examples/parse_packet.rs (line 12)
3fn main() -> Result<(), libaprs_engine::ParseError> {
4    let packet = parse_packet(b"N0CALL>APRS:>hello")?;
5
6    println!("source={}", String::from_utf8_lossy(packet.source()));
7    println!(
8        "destination={}",
9        String::from_utf8_lossy(packet.destination())
10    );
11
12    if let AprsData::Status { text } = packet.aprs_data() {
13        println!("status={}", String::from_utf8_lossy(text));
14    }
15
16    Ok(())
17}
More examples
Hide additional examples
examples/service_toolkit.rs (line 25)
10fn main() -> Result<(), libaprs_engine::ParseError> {
11    let mut engine = Engine::default();
12    let mut duplicates = DuplicateWindow::new(128);
13    let mut rate = PacketRateBudget::new(100);
14    let blocked = SemanticBlocklist::new(&[SemanticFamily::Unsupported, SemanticFamily::Malformed]);
15
16    for packet_bytes in [b"N0CALL>APRS:>service".as_slice()] {
17        if rate.try_consume() == RateLimitDecision::Limited {
18            continue;
19        }
20        if duplicates.observe(packet_bytes) == DuplicateDecision::Duplicate {
21            continue;
22        }
23
24        let packet = parse_packet(packet_bytes)?;
25        if blocked.rejects(&packet.aprs_data()) {
26            continue;
27        }
28
29        let _event = engine.process_event(packet.raw().as_bytes());
30    }
31
32    Ok(())
33}
pub fn summary(&self) -> PacketSummary<'_>

Returns a structured diagnostic summary for observability.

Examples found in repository?
examples/process_file.rs (line 19)
7fn main() -> std::io::Result<()> {
8    let Some(path) = std::env::args().nth(1) else {
9        eprintln!("usage: process_file <packets.aprs>");
10        std::process::exit(2);
11    };
12
13    let input = read_all_with_limit(File::open(path)?, DEFAULT_TRANSPORT_READ_LIMIT)?;
14    let mut engine = Engine::new(Policy::strict());
15
16    for packet_bytes in LineTransport::new(&input).packets() {
17        match engine.process(packet_bytes) {
18            EngineResult::Accepted { packet } => {
19                let summary = packet.summary();
20                println!(
21                    "accepted source={} destination={} semantic={}",
22                    String::from_utf8_lossy(summary.source),
23                    String::from_utf8_lossy(summary.destination),
24                    summary.semantic
25                );
26            }
27            EngineResult::Rejected { reason, .. } => eprintln!("rejected: {}", reason.code()),
28            EngineResult::ParseError(error) => eprintln!("malformed: {}", error.code()),
29        }
30    }
31
32    Ok(())
33}
More examples
Hide additional examples
examples/encode_packets.rs (line 35)
8fn main() -> Result<(), Box<dyn std::error::Error>> {
9    let path = [b"APRS".as_slice(), b"WIDE1-1".as_slice()];
10
11    let status = encode_status(b"N0CALL", &path, b"encoder example")?;
12    assert_eq!(
13        parse_packet(&status)
14            .map_err(|error| std::io::Error::new(std::io::ErrorKind::InvalidData, error.code()))?
15            .raw()
16            .as_bytes(),
17        b"N0CALL>APRS,WIDE1-1:>encoder example"
18    );
19
20    let position = encode_uncompressed_position(
21        b"N0CALL",
22        &path,
23        UncompressedPositionEncoding {
24            messaging: false,
25            latitude: b"4903.50N",
26            symbol_table: b'/',
27            longitude: b"07201.75W",
28            symbol_code: b'-',
29            comment: b"encoded",
30        },
31    )?;
32    assert_eq!(
33        parse_packet(&position)
34            .map_err(|error| std::io::Error::new(std::io::ErrorKind::InvalidData, error.code()))?
35            .summary()
36            .semantic,
37        "position"
38    );
39
40    let telemetry = encode_telemetry(b"N0CALL", &path, 1, [111, 222, 33, 44, 55], None)?;
41    assert_eq!(
42        parse_packet(&telemetry)
43            .map_err(|error| std::io::Error::new(std::io::ErrorKind::InvalidData, error.code()))?
44            .summary()
45            .semantic,
46        "telemetry"
47    );
48
49    Ok(())
50}
examples/service_ingest.rs (line 17)
5fn main() -> Result<(), std::io::Error> {
6    let input = b"N0CALL>APRS:>service online\nN1CALL>APRS:~opaque\nbad packet\n";
7    let mut engine = Engine::new(Policy::strict());
8
9    let packets = LineTransport::new(input).packets_with_limit(MAX_PACKET_LEN)?;
10
11    for packet in packets {
12        match engine.process_event(packet) {
13            EngineEvent::Accepted(event) => {
14                println!(
15                    "event={} semantic={}",
16                    event.kind().code(),
17                    event.packet.summary().semantic
18                );
19            }
20            EngineEvent::Rejected(event) => {
21                println!(
22                    "event={} code={} remediation={}",
23                    event.kind().code(),
24                    event.diagnostic.code,
25                    event.diagnostic.remediation
26                );
27            }
28            EngineEvent::Malformed(event) => {
29                println!(
30                    "event={} code={} raw_len={} raw_truncated={} remediation={}",
31                    event.kind().code(),
32                    event.diagnostic.code,
33                    event.raw.len(),
34                    event.raw_truncated,
35                    event.diagnostic.remediation
36                );
37            }
38        }
39    }
40
41    let counters = engine.counters();
42    println!(
43        "summary accepted={} rejected={} malformed={}",
44        counters.accepted, counters.rejected, counters.malformed
45    );
46
47    Ok(())
48}