WeatherFields

Struct WeatherFields 

pub struct WeatherFields<'a> {
Show 14 fields pub timestamp: Option<&'a [u8]>, pub wind_direction_degrees: Option<u16>, pub wind_speed_mph: Option<u16>, pub wind_gust_mph: Option<u16>, pub temperature_fahrenheit: Option<i16>, pub rain_last_hour_hundredths_inch: Option<u16>, pub rain_last_24_hours_hundredths_inch: Option<u16>, pub rain_since_midnight_hundredths_inch: Option<u16>, pub humidity_percent: Option<u16>, pub pressure_tenths_hpa: Option<u16>, pub luminosity_watts_per_square_meter: Option<u16>, pub luminosity_1000_plus_watts_per_square_meter: Option<u16>, pub snow_last_24_hours_inches: Option<u16>, pub raw_rain_counter: Option<u16>,
}
Extracted numeric weather fields.

Fields

timestamp: Option<&'a [u8]>

Optional six-byte timestamp prefix.

wind_direction_degrees: Option<u16>

Wind direction in degrees.

wind_speed_mph: Option<u16>

Sustained wind speed in miles per hour.

wind_gust_mph: Option<u16>

Wind gust speed in miles per hour.

temperature_fahrenheit: Option<i16>

Temperature in degrees Fahrenheit.

rain_last_hour_hundredths_inch: Option<u16>

Rain in the last hour, in hundredths of an inch.

rain_last_24_hours_hundredths_inch: Option<u16>

Rain in the last 24 hours, in hundredths of an inch.

rain_since_midnight_hundredths_inch: Option<u16>

Rain since midnight, in hundredths of an inch.

humidity_percent: Option<u16>

Relative humidity percent.

pressure_tenths_hpa: Option<u16>

Barometric pressure in tenths of hPa.

luminosity_watts_per_square_meter: Option<u16>

Luminosity in watts per square meter from Lnnn.

luminosity_1000_plus_watts_per_square_meter: Option<u16>

Luminosity in watts per square meter from lnnn, representing 1000+.

snow_last_24_hours_inches: Option<u16>

Snowfall in the last 24 hours, in inches.

raw_rain_counter: Option<u16>

Raw rain counter value from #nnn.