pub enum PolicyRejection {
PathTooLong,
MalformedSemantics,
UnsupportedSemantics,
InvalidNmeaChecksum,
}Expand description
Policy rejection reason.
Variants
PathTooLong
Path contains too many components.
MalformedSemantics
Semantic payload is malformed.
UnsupportedSemantics
Semantic payload is unsupported.
InvalidNmeaChecksum
NMEA sentence has a present checksum that does not match.
Implementations
Sourceimpl PolicyRejection
impl PolicyRejection
Sourcepub fn code(self) -> &'static str
pub fn code(self) -> &'static str
Returns a stable policy rejection code for logs and external systems.
Examples found in repository?
examples/process_file.rs (line 19)
7fn main() -> std::io::Result<()> {
8 let Some(path) = std::env::args().nth(1) else {
9 eprintln!("usage: process_file <packets.aprs>");
10 std::process::exit(2);
11 };
12
13 let input = read_all_with_limit(File::open(path)?, DEFAULT_TRANSPORT_READ_LIMIT)?;
14 let mut engine = Engine::new(Policy::strict());
15
16 for packet_bytes in LineTransport::new(&input).packets() {
17 match engine.process(packet_bytes) {
18 EngineResult::Accepted { packet } => println!("{}", packet.to_json()),
19 EngineResult::Rejected { reason, .. } => eprintln!("rejected: {}", reason.code()),
20 EngineResult::ParseError(error) => eprintln!("malformed: {}", error.code()),
21 }
22 }
23
24 Ok(())
25}Trait Implementations
Sourceimpl Clone for PolicyRejection
impl Clone for PolicyRejection
Sourcefn clone(&self) -> PolicyRejection
fn clone(&self) -> PolicyRejection
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PolicyRejection
impl Debug for PolicyRejection
Sourceimpl PartialEq for PolicyRejection
impl PartialEq for PolicyRejection
impl Copy for PolicyRejection
impl Eq for PolicyRejection
impl StructuralPartialEq for PolicyRejection