pub enum DuplicateDecision {
New,
Duplicate,
}Expand description
Duplicate suppression decision for a packet byte sequence.
Variants
New
Packet bytes were not seen in the retained window.
Duplicate
Packet bytes match a retained packet in the window.
Implementations