pub struct DuplicateWindow { /* private fields */ }Expand description
Bounded exact-byte duplicate window.
Implementations
Sourceimpl DuplicateWindow
impl DuplicateWindow
Sourcepub const fn new(capacity: usize) -> Self
pub const fn new(capacity: usize) -> Self
Creates a duplicate window retaining at most capacity packet byte
sequences. A zero-capacity window never retains packets.
Examples found in repository?
examples/service_toolkit.rs (line 12)
10fn main() -> Result<(), libaprs_engine::ParseError> {
11 let mut engine = Engine::default();
12 let mut duplicates = DuplicateWindow::new(128);
13 let mut rate = PacketRateBudget::new(100);
14 let blocked = SemanticBlocklist::new(&[SemanticFamily::Unsupported, SemanticFamily::Malformed]);
15
16 for packet_bytes in [b"N0CALL>APRS:>service".as_slice()] {
17 if rate.try_consume() == RateLimitDecision::Limited {
18 continue;
19 }
20 if duplicates.observe(packet_bytes) == DuplicateDecision::Duplicate {
21 continue;
22 }
23
24 let packet = parse_packet(packet_bytes)?;
25 if blocked.rejects(&packet.aprs_data()) {
26 continue;
27 }
28
29 let _event = engine.process_event(packet.raw().as_bytes());
30 }
31
32 Ok(())
33}Sourcepub fn observe(&mut self, packet: &[u8]) -> DuplicateDecision
pub fn observe(&mut self, packet: &[u8]) -> DuplicateDecision
Observes packet bytes and reports whether the exact bytes were recently retained.
Examples found in repository?
examples/service_toolkit.rs (line 20)
10fn main() -> Result<(), libaprs_engine::ParseError> {
11 let mut engine = Engine::default();
12 let mut duplicates = DuplicateWindow::new(128);
13 let mut rate = PacketRateBudget::new(100);
14 let blocked = SemanticBlocklist::new(&[SemanticFamily::Unsupported, SemanticFamily::Malformed]);
15
16 for packet_bytes in [b"N0CALL>APRS:>service".as_slice()] {
17 if rate.try_consume() == RateLimitDecision::Limited {
18 continue;
19 }
20 if duplicates.observe(packet_bytes) == DuplicateDecision::Duplicate {
21 continue;
22 }
23
24 let packet = parse_packet(packet_bytes)?;
25 if blocked.rejects(&packet.aprs_data()) {
26 continue;
27 }
28
29 let _event = engine.process_event(packet.raw().as_bytes());
30 }
31
32 Ok(())
33}Sourcepub fn retained_len(&self) -> usize
pub fn retained_len(&self) -> usize
Returns the number of packet byte sequences currently retained.