PacketRateBudget

Struct PacketRateBudget 

pub struct PacketRateBudget { /* private fields */ }
Caller-reset packet-rate budget.

Implementations

Source

impl PacketRateBudget

pub const fn new(limit: u64) -> Self

Creates a packet-rate budget with limit allowed packets per caller-owned window.

Examples found in repository?
examples/service_toolkit.rs (line 13)
10fn main() -> Result<(), libaprs_engine::ParseError> {
11    let mut engine = Engine::default();
12    let mut duplicates = DuplicateWindow::new(128);
13    let mut rate = PacketRateBudget::new(100);
14    let blocked = SemanticBlocklist::new(&[SemanticFamily::Unsupported, SemanticFamily::Malformed]);
15
16    for packet_bytes in [b"N0CALL>APRS:>service".as_slice()] {
17        if rate.try_consume() == RateLimitDecision::Limited {
18            continue;
19        }
20        if duplicates.observe(packet_bytes) == DuplicateDecision::Duplicate {
21            continue;
22        }
23
24        let packet = parse_packet(packet_bytes)?;
25        if blocked.rejects(&packet.aprs_data()) {
26            continue;
27        }
28
29        let _event = engine.process_event(packet.raw().as_bytes());
30    }
31
32    Ok(())
33}
pub fn try_consume(&mut self) -> RateLimitDecision

Attempts to consume one packet from the current budget.

Examples found in repository?
examples/service_toolkit.rs (line 17)
10fn main() -> Result<(), libaprs_engine::ParseError> {
11    let mut engine = Engine::default();
12    let mut duplicates = DuplicateWindow::new(128);
13    let mut rate = PacketRateBudget::new(100);
14    let blocked = SemanticBlocklist::new(&[SemanticFamily::Unsupported, SemanticFamily::Malformed]);
15
16    for packet_bytes in [b"N0CALL>APRS:>service".as_slice()] {
17        if rate.try_consume() == RateLimitDecision::Limited {
18            continue;
19        }
20        if duplicates.observe(packet_bytes) == DuplicateDecision::Duplicate {
21            continue;
22        }
23
24        let packet = parse_packet(packet_bytes)?;
25        if blocked.rejects(&packet.aprs_data()) {
26            continue;
27        }
28
29        let _event = engine.process_event(packet.raw().as_bytes());
30    }
31
32    Ok(())
33}
pub fn reset(&mut self)

Resets the current budget back to the configured limit.

pub const fn limit(&self) -> u64

Returns the configured packet limit.

pub const fn remaining(&self) -> u64

Returns the remaining packet budget in the current caller-owned window.